==> haskell-bower-json-1.1.0.0-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-BlgvwXVauRdICt4OAAQjQn
key:                  bower-json-1.1.0.0-BlgvwXVauRdICt4OAAQjQn
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  23dd40ec5cf889c7d3b9f588b0a0eb14
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-BlgvwXVauRdICt4OAAQjQn
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb
    aeson-better-errors-0.9.1.3-KCHcQ5snOS0ILx8YJVHUlV base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1 mtl-2.2.2
    scientific-0.3.8.0-4NIM1ptKK7Y3EgpQdVTV5l text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR
    vector-0.13.2.0-B39FQf4cXUZ2GlwNF0TDTd

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.1.0.0-177-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-C7OEhMfGbBd6ErLcaYLhkT
key:                  bower-json-1.1.0.0-C7OEhMfGbBd6ErLcaYLhkT
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  b55f377e43fad9c43b3064b5654316a7
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-C7OEhMfGbBd6ErLcaYLhkT
depends:
    aeson-2.1.2.1-KxhFBZPQYXiG3TO3nhA4Kq
    aeson-better-errors-0.9.1.3-HtTxqM9Tqyi2AQb6C0OMAN base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1 mtl-2.2.2
    scientific-0.3.8.0-4yENNWrElASJBAecoCEn1P text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Ee1qJYwM3Cx9FXWFU8Ujy3
    vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
